Module common

Module common 

Types

Re-exports

pub use crate::wallet::ProofInfo;

Structs

FeeReserve
Mint Fee Reserve
FinalizedMelt
Result of a finalized melt operation
IssuerVersion
CDK Version
PaymentProcessorKey
Key used in hashmap of ln backends to identify what unit and payment method it is for
QuoteTTL
Seconds quotes are valid