pub struct LockedMeltQuotes {
pub target: Option<Acquired<MeltQuote>>,
pub all_related: Vec<Acquired<MeltQuote>>,
}Expand description
Result of locking a melt quote and all related quotes atomically.
This struct is returned by QuotesTransaction::lock_melt_quote_and_related
and contains both the target quote and all quotes sharing the same request_lookup_id.
Fields
target: Option<Acquired<MeltQuote>>The target quote that was requested, if found
All quotes sharing the same request_lookup_id (including the target)