Module nut02

Module nut02 

Structs

Id
A keyset ID is an identifier for a specific keyset. It can be derived by anyone who knows the set of public keys of a mint. The keyset ID CAN be stored in a Cashu token such that the token can be used to identify which mint or keyset it was generated from.
KeySet
Keyset
KeySetInfo
KeySetInfo
KeysetResponse
Mint Keysets [NUT-02] Ids of mints keyset ids
MintKeySet
Mint keyset.
ShortKeysetId
Improper prefix of the keyset ID. In case of v1, this is the whole ID. In case of v2, this is the 8-byte prefix

Enums

Error
NUT02 Error
IdBytes
Keyset ID bytes
KeySetVersion
Keyset version

Traits

KeySetInfosMethods
Utility methods for KeySetInfos

Type Aliases

KeySetInfos
List of KeySetInfo