Module nut11

Module nut11 

NUT-11: Pay to Public Key (P2PK)

https://github.com/cashubtc/nuts/blob/main/11.md

Modules

serde_p2pk_witness
Serde utils for P2PK Witness

Structs

EnforceSigFlag
Enforce Sigflag info
P2PKWitness
P2Pk Witness

Enums

Error
Nut11 Error
SigFlag
Signature flag

Functions

enforce_sig_flag
Get the signature flag that should be enforced for a set of proofs and the public keys that signatures are valid for