pub struct NotificationInner<T, I>where
T: Clone,{
pub sub_id: I,
pub payload: NotificationPayload<T>,
}Expand description
The notification
This is the notification that is sent to the client when an event matches a subscription
This type is serialize-only in practice: notification payloads are not
self-describing. Clients should deserialize notifications as
RawNotificationInner and decode the payload with
deserialize_payload_for_kind, using
the kind of the subscription the notification belongs to.
Fields
sub_id: IThe subscription ID
payload: NotificationPayload<T>The notification payload