pub struct MeltQuoteOnchainFeeOption {
pub fee_index: u32,
pub fee_reserve: Amount,
pub estimated_blocks: u32,
}Expand description
Fee option for an onchain melt quote.
Each item in an onchain melt quote’s fee_options represents one
available fee reserve and confirmation estimate for the same payment. The wallet
selects one option when executing the quote by echoing its
fee_index value in the melt request.
The mint enforces these NUT rules on the fee_options list as a whole:
- MUST return at least one item.
- MUST NOT contain two items with the same
fee_index. - The list is fixed for the lifetime of the quote.
Fields
fee_index: u32Server-assigned identifier the wallet echoes back to select this option
fee_reserve: AmountMaximum onchain transaction fee the mint may charge for this option
estimated_blocks: u32Estimated number of blocks until confirmation