pub struct MintQuoteOnchainResponse<Q> {
pub quote: Q,
pub request: String,
pub unit: CurrencyUnit,
pub expiry: Option<u64>,
pub pubkey: PublicKey,
pub amount_paid: Amount,
pub amount_issued: Amount,
}Expand description
Mint quote onchain response
Response containing the onchain quote details.
Unknown fields are accepted to preserve forward compatibility when mints add optional onchain extensions.
Fields
quote: QQuote Id
request: StringBitcoin address to send funds to
unit: CurrencyUnitUnit
expiry: Option<u64>Unix timestamp until the quote is valid
pubkey: PublicKeyNUT-20 Pubkey from the request
amount_paid: AmountTotal confirmed amount paid to the request
amount_issued: AmountAmount of ecash that has been issued for the given mint quote
Implementations
Sourceimpl<Q> MintQuoteOnchainResponse<Q>where
Q: ToString,
impl<Q> MintQuoteOnchainResponse<Q>where
Q: ToString,
Sourcepub fn to_string_id(&self) -> MintQuoteOnchainResponse<String>
pub fn to_string_id(&self) -> MintQuoteOnchainResponse<String>
Convert the MintQuoteOnchainResponse with a quote type Q to a String