pub struct OnchainSettings {
pub confirmations: u32,
pub min_receive_amount_sat: u64,
pub min_send_amount_sat: u64,
}Expand description
Onchain settings
Fields
confirmations: u32Number of confirmations required
min_receive_amount_sat: u64Minimum incoming onchain payment amount accepted by the backend
min_send_amount_sat: u64Minimum outgoing onchain payment amount accepted by the backend