pub struct Subscriber<S>where
S: Spec + 'static,{ /* private fields */ }Expand description
Lightweight sink used by producers to send events to subscribers.
You usually do not construct a Subscriber directly — it is provided to you in
the Spec::fetch_events callback so you can backfill a new subscription.
Implementations
Sourceimpl<S> Subscriber<S>where
S: Spec + 'static,
impl<S> Subscriber<S>where
S: Spec + 'static,