PaymentRequestBuilder

Struct PaymentRequestBuilder 

pub struct PaymentRequestBuilder { /* private fields */ }
Builder for PaymentRequest

Implementations

Source

impl PaymentRequestBuilder

pub fn payment_id<S>(self, payment_id: S) -> PaymentRequestBuilder
where S: Into<String>,

Set payment ID

pub fn amount<A>(self, amount: A) -> PaymentRequestBuilder
where A: Into<Amount>,

Set requested amount.

Call Self::unit as well to produce a spec-valid fixed-amount request.

pub fn unit(self, unit: CurrencyUnit) -> PaymentRequestBuilder

Set unit

pub fn single_use(self, single_use: bool) -> PaymentRequestBuilder

Set single use flag

pub fn add_mint(self, mint_url: MintUrl) -> PaymentRequestBuilder

Add a mint URL

pub fn mints(self, mints: Vec<MintUrl>) -> PaymentRequestBuilder

Set mint URLs the receiver accepts or prefers.

Unless Self::mint_preferred is set to true, a non-empty list is strict.

pub fn mint_preferred(self, mint_preferred: bool) -> PaymentRequestBuilder

Set whether the mint list is preferred instead of strict.

true means the payer should prefer listed mints but may use other mints. false means the payer must only use listed mints. Omit this field to get the same strict behavior as false.

pub fn supported_methods( self, methods: Vec<SupportedMethod>, ) -> PaymentRequestBuilder

Set payment methods the payer’s mint must support.

pub fn add_supported_method( self, method: SupportedMethod, ) -> PaymentRequestBuilder

Add a payment method the payer’s mint must support.

pub fn description<S>(self, description: S) -> PaymentRequestBuilder
where S: Into<String>,

Set description

pub fn add_transport(self, transport: Transport) -> PaymentRequestBuilder

Add a transport

pub fn transports(self, transports: Vec<Transport>) -> PaymentRequestBuilder

Set transports

pub fn nut10(self, nut10: Nut10SecretRequest) -> PaymentRequestBuilder

Set Nut10 secret

pub fn build(self) -> PaymentRequest

Build the PaymentRequest