pub struct Proof {
pub amount: Amount,
pub keyset_id: Id,
pub secret: Secret,
pub c: PublicKey,
pub witness: Option<Witness>,
pub dleq: Option<ProofDleq>,
}Expand description
Proofs
Fields
amount: AmountAmount
keyset_id: IdKeyset id
secret: SecretSecret message
c: PublicKeyUnblinded signature
witness: Option<Witness>Witness
dleq: Option<ProofDleq>DLEQ Proof
Implementations
Sourceimpl Proof
impl Proof
Sourceimpl Proof
impl Proof
Sourcepub fn verify_p2pk(&self) -> Result<(), Error>
pub fn verify_p2pk(&self) -> Result<(), Error>
Verify P2PK signature on Proof
Per NUT-11, there are two spending pathways after locktime:
- Primary path (data + pubkeys): ALWAYS available
- Refund path (refund keys): available AFTER locktime
The verification tries both paths - if either succeeds, the proof is valid.
Sourceimpl Proof
impl Proof
Sourcepub fn verify_htlc(&self) -> Result<(), Error>
pub fn verify_htlc(&self) -> Result<(), Error>
Verify HTLC
Per NUT-14, there are two spending pathways:
- Receiver path (preimage + pubkeys): ALWAYS available
- Sender/Refund path (refund keys, no preimage): available AFTER locktime
The verification tries to determine which path is being used based on the witness provided, then validates accordingly.
Sourcepub fn add_preimage(&mut self, preimage: String)
pub fn add_preimage(&mut self, preimage: String)
Add Preimage