pub fn spawn<F>(future: F) -> JoinHandle<F::Output> ⓘExpand description
Spawns a new asynchronous task returning nothing
Panics
Panics if the global Tokio runtime cannot be created when no runtime exists on the current thread.
pub fn spawn<F>(future: F) -> JoinHandle<F::Output> ⓘSpawns a new asynchronous task returning nothing
Panics if the global Tokio runtime cannot be created when no runtime exists on the current thread.