pub struct MintOperationData {
pub is_batch: Option<bool>,
pub amount: Amount,
pub counter_start: Option<u32>,
pub counter_end: Option<u32>,
pub blinded_messages: Option<Vec<BlindedMessage>>,
/* private fields */
}Expand description
Operation-specific data for Mint operations
Fields
is_batch: Option<bool>Whether this is a batch operation
True if this was created by batch_mint, false for single mint. Used to determine which endpoint to use for replay.
amount: AmountAmount to mint (total for batch)
counter_start: Option<u32>Derivation counter start
counter_end: Option<u32>Derivation counter end
blinded_messages: Option<Vec<BlindedMessage>>Blinded messages for recovery
Stored so that if a crash occurs after the mint accepts the request, we can use these to query the mint for signatures and reconstruct proofs.
Implementations
Sourceimpl MintOperationData
impl MintOperationData
Sourcepub fn new_single(
quote_id: String,
amount: Amount,
counter_start: Option<u32>,
counter_end: Option<u32>,
blinded_messages: Option<Vec<BlindedMessage>>,
) -> Self
pub fn new_single( quote_id: String, amount: Amount, counter_start: Option<u32>, counter_end: Option<u32>, blinded_messages: Option<Vec<BlindedMessage>>, ) -> Self
Create operation data for a single-quote mint operation.
Sourcepub fn new_batch(
quote_ids: Vec<String>,
amount: Amount,
counter_start: Option<u32>,
counter_end: Option<u32>,
blinded_messages: Option<Vec<BlindedMessage>>,
) -> Self
pub fn new_batch( quote_ids: Vec<String>, amount: Amount, counter_start: Option<u32>, counter_end: Option<u32>, blinded_messages: Option<Vec<BlindedMessage>>, ) -> Self
Create operation data for a batch mint operation.
Sourcepub fn primary_quote_id(&self) -> &str
pub fn primary_quote_id(&self) -> &str
Get the representative quote ID for this operation.