pub struct SwapOperationData {
pub input_amount: Amount,
pub output_amount: Amount,
pub counter_start: Option<u32>,
pub counter_end: Option<u32>,
pub blinded_messages: Option<Vec<BlindedMessage>>,
}Expand description
Operation-specific data for Swap operations
Fields
input_amount: AmountInput amount
output_amount: AmountOutput amount
counter_start: Option<u32>Derivation counter start
counter_end: Option<u32>Derivation counter end
blinded_messages: Option<Vec<BlindedMessage>>Blinded messages for recovery
Stored so that if a crash occurs after the mint accepts the swap, we can use these to query the mint for signatures and reconstruct proofs.