Types
Re-exports
pub use crate::wallet::ProofInfo;
Structs
- FeeReserve
- Mint Fee Reserve
- Finalized
Melt - Result of a finalized melt operation
- Issuer
Version - CDK Version
- Payment
Processor Key - Key used in hashmap of ln backends to identify what unit and payment method it is for
- QuoteTTL
- Seconds quotes are valid