pub struct MeltOperationData {
pub quote_id: String,
pub amount: Amount,
pub fee_reserve: Amount,
pub counter_start: Option<u32>,
pub counter_end: Option<u32>,
pub change_amount: Option<Amount>,
pub change_blinded_messages: Option<Vec<BlindedMessage>>,
}Expand description
Operation-specific data for Melt operations
Fields
quote_id: StringQuote ID
amount: AmountAmount to melt
fee_reserve: AmountFee reserve
counter_start: Option<u32>Derivation counter start
counter_end: Option<u32>Derivation counter end
change_amount: Option<Amount>Change amount (if any)
change_blinded_messages: Option<Vec<BlindedMessage>>Blinded messages for change recovery
Stored so that if a crash occurs after the mint accepts the melt, we can use these to query the mint for change signatures and reconstruct proofs.